PN: update-rc.d
PV: 0.8+git
PR: r0
PKGV: 0.8+git0+b8f9501050
PKGR: r0.0
LICENSE: GPL-2.0-or-later
DESCRIPTION: update-rc.d is a utility that allows the management of symlinks to the initscripts in the /etc/rcN.d directory structure.
SUMMARY: manage symlinks in /etc/rcN.d
SECTION: base
PKG:update-rc.d: update-rc.d
FILES:update-rc.d: /usr/bin/* /usr/sbin/* /usr/libexec/* /usr/lib/lib*.so.*             /etc /com /var             /usr/bin/* /usr/sbin/*             /usr/lib/*.so.*             /lib/udev /usr/lib/udev             /usr/lib/udev /usr/lib/udev             /usr/share/update-rc.d /usr/lib/update-rc.d/*             /usr/share/pixmaps /usr/share/applications             /usr/share/idl /usr/share/omf /usr/share/sounds             /usr/lib/bonobo/servers
FILES_INFO:update-rc.d: {"/usr/sbin/update-rc.d": 6388}
FILERDEPENDSFLIST:update-rc.d: /usr/sbin/update-rc.d
FILERDEPENDS:/usr/sbin/update-rc.d:update-rc.d:  /bin/sh
PKGSIZE:update-rc.d: 6388
